@@ -44,6 +44,7 @@ typedef enum
     AdvancedSearchComplete = 0xFA6A,
     AdvancedSearchStopped = 0xFA6B,
     AttachmentContextMenuDisplay = 0xFB3E,
+    BeforePrint = 0xFC8E,
     BeforeFolderSharingDialog = 0xFC01,
     ContextMenuClose = 0xFBA6,
     FolderContextMenuDisplay = 0xFB42,
@@ -62,14 +63,30 @@ typedef enum
     ViewContextMenuDisplay = 0xFB40
   } ApplicationEvent;
 
+static bool beforePrintSeen;
+
 EVENT_SINK_INVOKE(ApplicationEvents)
 {
   USE_INVOKE_ARGS
   switch(dispid)
     {
+      case BeforePrint:
+        {
+          log_debug ("%s:%s: BeforePrint seen.",
+                     SRCNAME, __func__);
+          beforePrintSeen = true;
+          break;
+        }
       case ItemLoad:
         {
           TSTART;
+          if (g_ignore_next_load)
+            {
+              log_debug ("%s:%s: Ignore ItemLoad because ignore next "
+                         "load is true", SRCNAME, __func__);
+              g_ignore_next_load = false;
+              TBREAK;
+            }
           LPDISPATCH mailItem;
           /* The mailItem should be the first argument */
           if (!parms || parms->cArgs != 1 ||
@@ -86,13 +103,19 @@ EVENT_SINK_INVOKE(ApplicationEvents)
                                        IID_MailItem);
           if (!mailItem)
             {
-              log_debug ("%s:%s: ItemLoad event without mailitem.",
+              beforePrintSeen = false;
+              log_debug ("%s:%s: ItemLoad is not for a mail.",
                          SRCNAME, __func__);
               TBREAK;
             }
           log_debug ("%s:%s: Creating mail object for item: %p",
                      SRCNAME, __func__, mailItem);
-          new Mail (mailItem);
+          auto mail = new Mail (mailItem);
+          if (beforePrintSeen)
+            {
+              mail->setIsPrint (true);
+            }
+          beforePrintSeen = false;
           do_in_ui_thread_async (INVALIDATE_LAST_MAIL, nullptr);
           TBREAK;
         }
@@ -112,4 +135,4 @@ EVENT_SINK_INVOKE(ApplicationEvents)
      anyway if everything works as documented. */
   return S_OK;
 }
-END_EVENT_SINK(ApplicationEvents, IID_ApplicationEvents)
+END_EVENT_SINK(ApplicationEvents, IID_ApplicationEvents_11)
