@@ -125,7 +125,7 @@ start_watchdog (LPVOID arg)
   LPDISPATCH explorer = (LPDISPATCH) arg;
 
   Sleep (500);
-  gpgrt_lock_lock (&explorer_map_lock);
+  gpgol_lock (&explorer_map_lock);
 
   auto it = s_explorerMap.find (explorer);
 
@@ -133,13 +133,13 @@ start_watchdog (LPVOID arg)
     {
       log_error ("%s:%s: Watchdog for unknwon explorer %p",
                  SRCNAME, __func__, explorer);
-      gpgrt_lock_unlock (&explorer_map_lock);
+      gpgol_unlock (&explorer_map_lock);
       return 0;
     }
 
   if ((it->second & SelectSeen))
     {
-      log_oom_extra ("%s:%s: Cancel watchdog as we have seen a select %p",
+      log_oom ("%s:%s: Cancel watchdog as we have seen a select %p",
                      SRCNAME, __func__, explorer);
       it->second = SelectSeen;
     }
@@ -148,11 +148,11 @@ start_watchdog (LPVOID arg)
       log_debug ("%s:%s: Deteced unselect invalidating UI.",
                  SRCNAME, __func__);
       it->second = UnselectSeen;
-      gpgrt_lock_unlock (&explorer_map_lock);
+      gpgol_unlock (&explorer_map_lock);
       do_in_ui_thread (INVALIDATE_UI, nullptr);
       return 0;
     }
-  gpgrt_lock_unlock (&explorer_map_lock);
+  gpgol_unlock (&explorer_map_lock);
 
   return 0;
 }
@@ -160,7 +160,7 @@ start_watchdog (LPVOID arg)
 static void
 changeSeen (LPDISPATCH explorer)
 {
-  gpgrt_lock_lock (&explorer_map_lock);
+  gpgol_lock (&explorer_map_lock);
 
   auto it = s_explorerMap.find (explorer);
 
@@ -175,14 +175,14 @@ changeSeen (LPDISPATCH explorer)
   if (has_selection)
     {
       it->second = (state & WatchDogActive) + SelectSeen;
-      log_oom_extra ("%s:%s: Seen select for %p",
+      log_oom ("%s:%s: Seen select for %p",
                      SRCNAME, __func__, explorer);
     }
   else
     {
       if ((it->second & WatchDogActive))
         {
-          log_oom_extra ("%s:%s: Seen unselect for %p but watchdog exists.",
+          log_oom ("%s:%s: Seen unselect for %p but watchdog exists.",
                          SRCNAME, __func__, explorer);
         }
       else
@@ -192,7 +192,7 @@ changeSeen (LPDISPATCH explorer)
         }
       it->second = UnselectSeen + WatchDogActive;
     }
-  gpgrt_lock_unlock (&explorer_map_lock);
+  gpgol_unlock (&explorer_map_lock);
 }
 
 EVENT_SINK_INVOKE(ExplorerEvents)
@@ -202,27 +202,27 @@ EVENT_SINK_INVOKE(ExplorerEvents)
     {
       case SelectionChange:
         {
-          log_oom_extra ("%s:%s: Selection change in explorer: %p",
+          log_oom ("%s:%s: Selection change in explorer: %p",
                          SRCNAME, __func__, this);
           changeSeen (m_object);
           break;
         }
       case Close:
         {
-          log_oom_extra ("%s:%s: Deleting event handler: %p",
+          log_oom ("%s:%s: Deleting event handler: %p",
                          SRCNAME, __func__, this);
 
           GpgolAddin::get_instance ()->unregisterExplorerSink (this);
-          gpgrt_lock_lock (&explorer_map_lock);
+          gpgol_lock (&explorer_map_lock);
           s_explorerMap.erase (m_object);
-          gpgrt_lock_unlock (&explorer_map_lock);
+          gpgol_unlock (&explorer_map_lock);
           delete this;
           return S_OK;
         }
       default:
         break;
 #if 0
-        log_oom_extra ("%s:%s: Unhandled Event: %lx \n",
+        log_oom ("%s:%s: Unhandled Event: %lx \n",
                        SRCNAME, __func__, dispid);
 #endif
     }
